==> owncloud-app-calendar-1%3A1.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/et_EE.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "Individual" : "Individuaalne",
    "Group" : "Grupp",
    "Resource" : "Ressurss",
    "Room" : "Ruum",
    "Unknown" : "Tundmatu",
    "Required" : "Kohustuslik",
    "Optional" : "Valikuline",
    "Does not attend" : "Ei võta soa",
    "New event" : "Uus sündmus",
    "Attendees" : "Osalejad",
    "Reminders" : "Meelespead",
    "Repeating" : "Kordamine",
    "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
    "Please add a title!" : "Palu lisa pealkiri!",
    "Please select a calendar!" : "Palun vali kalender!",
    "Global" : "Üldine",
    "None" : "Pole",
    "Every day" : "Iga päev",
    "Every week" : "Iga nädal",
    "Every month" : "Iga kuu",
    "Every year" : "Iga aasta",
    "never" : "mitte kunagi",
    "after" : "pärast",
    "At time of event" : "Sündmuse aeg",
    "5 minutes before" : "5 minutit enne",
    "10 minutes before" : "10 minutit enne",
    "15 minutes before" : "15 minutit enne",
    "30 minutes before" : "30 minutit enne",
    "1 hour before" : "1 tund enne",
    "2 hours before" : "2 tundi enne",
    "Custom" : "Kohandatud",
    "Audio" : "Helid",
    "E Mail" : "E-post",
    "Pop up" : "Hüpikaken",
    "sec" : "sek",
    "min" : "min",
    "hours" : "tundi",
    "days" : "päeva",
    "week" : "nädal",
    "before" : "enne",
    "start" : "algus",
    "end" : "lõpp",
    "Successfully imported" : "Imporditud",
    "Pop-up" : "Hüpikaken",
    "E-Mail" : "E-post",
    "{type} at {time}" : "{type} kell {time}",
    "{calendar} shared by {owner}" : "{calendar} jagas {owner}",
    "Title of the Event" : "Sündmuse pealkiri",
    "starts" : "algab",
    "ends" : "lõpeb",
    "All day Event" : "Kogu päeva sündmus",
    "Location" : "Asukoht",
    "Delete" : "Kustuta",
    "Cancel" : "Loobu",
    "More ..." : "Veel ...",
    "Create" : "Lisa",
    "Update" : "Uuenda",
    "Close" : "Sulge",
    "Description" : "Kirjeldus",
    "Export" : "Ekspordi",
    "Day" : "Päev",
    "Week" : "Nädal",
    "Month" : "Kuu",
    "Today" : "Täna",
    "Share Calendar" : "Jaga kalendrit",
    "More" : "Rohkem",
    "Edit" : "Muuda",
    "CalDAV" : "CalDAV",
    "group" : "grupp",
    "New Calendar" : "Uus kalender",
    "Subscriptions" : "Tellimused",
    "New Subscription" : "Uus tellimus",
    "Url" : "URL",
    "Edit event" : "Muuda sündmust",
    "Delete Event" : "Kustuta sündmus",
    "Save Event" : "Salvesta sündmus",
    "Time" : "Aeg",
    "Type" : "Tüüp",
    "Relative" : "Suhteline",
    "Absolute" : "Absoluutne",
    "Repeat" : "Korda",
    "times every" : "korda iga",
    "Add" : "Lisa",
    "from" : "alates",
    "to" : "kuni",
    "Reset repeating rule" : "Nulli kordamise reegel",
    "Repeat every ..." : "Korda iga ...",
    "end repeat ..." : "lõpeta kordamine",
    "times" : "korda",
    "Import Calendars" : "Impordi kalendreid",
    "Import canceled" : "Importimine on tühistatud",
    "Analyzing calendar" : "Kalendri analüüsimine",
    "New calendar" : "Uus kalender",
    "Import scheduled" : "Importimine on ajastatud",
    "Settings" : "Seaded",
    "Import calendar" : "Impordi kalender",
    "No Calendars selected for import" : "Pole valitud kalendreid, mida importida",
    "Primary CalDAV address" : "Primaarne CalDAV aadress",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV aadress"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-calendar-1%3A1.3.2-3-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/et_EE.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "Individual" : "Individuaalne",
    "Group" : "Grupp",
    "Resource" : "Ressurss",
    "Room" : "Ruum",
    "Unknown" : "Tundmatu",
    "Required" : "Kohustuslik",
    "Optional" : "Valikuline",
    "Does not attend" : "Ei võta soa",
    "Please create a calendar first." : "Palun loo esmalt kalender.",
    "New event" : "Uus sündmus",
    "Attendees" : "Osalejad",
    "Reminders" : "Meelespead",
    "Repeating" : "Kordamine",
    "When shared show full event" : "Kui on jagatud, siis näita kogu sündmust",
    "When shared show only busy" : "Kui on jagatud, siis näita ainult, kas on hõivatud",
    "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
    "Please add a title!" : "Palu lisa pealkiri!",
    "Please select a calendar!" : "Palun vali kalender!",
    "Global" : "Üldine",
    "None" : "Pole",
    "Every day" : "Iga päev",
    "Every week" : "Iga nädal",
    "Every month" : "Iga kuu",
    "Every year" : "Iga aasta",
    "never" : "mitte kunagi",
    "after" : "pärast",
    "At time of event" : "Sündmuse aeg",
    "5 minutes before" : "5 minutit enne",
    "10 minutes before" : "10 minutit enne",
    "15 minutes before" : "15 minutit enne",
    "30 minutes before" : "30 minutit enne",
    "1 hour before" : "1 tund enne",
    "2 hours before" : "2 tundi enne",
    "Custom" : "Kohandatud",
    "Audio" : "Helid",
    "E Mail" : "E-post",
    "Pop up" : "Hüpikaken",
    "sec" : "sek",
    "min" : "min",
    "hours" : "tundi",
    "days" : "päeva",
    "week" : "nädal",
    "before" : "enne",
    "start" : "algus",
    "end" : "lõpp",
    "Week {number} of {year}" : "Nädal nr. {number} aastas {year}",
    "Successfully imported" : "Imporditud",
    "Partially imported, 1 failure" : "Osaliselt imporditud, 1 ebaõnnestus",
    "Partially imported, {n} failures" : "Osaliselt imporditud, {n} ebaõnnestus",
    "Audio alarm" : "Helialarm",
    "Pop-up" : "Hüpikaken",
    "E-Mail" : "E-post",
    "{type} at {time}" : "{type} kell {time}",
    "{calendar} shared by {owner}" : "{calendar} jagas {owner}",
    "Title of the Event" : "Sündmuse pealkiri",
    "starts" : "algab",
    "ends" : "lõpeb",
    "All day Event" : "Kogu päeva sündmus",
    "Delete" : "Kustuta",
    "Cancel" : "Loobu",
    "More ..." : "Veel ...",
    "Create" : "Lisa",
    "Update" : "Uuenda",
    "Close" : "Sulge",
    "Location" : "Asukoht",
    "Description" : "Kirjeldus",
    "Export" : "Ekspordi",
    "Day" : "Päev",
    "Week" : "Nädal",
    "Month" : "Kuu",
    "Today" : "Täna",
    "Share Calendar" : "Jaga kalendrit",
    "More" : "Rohkem",
    "Edit" : "Muuda",
    "CalDAV" : "CalDAV",
    "can edit" : "saab muuta",
    "group" : "grupp",
    "New Calendar" : "Uus kalender",
    "Subscriptions" : "Tellimused",
    "New Subscription" : "Uus tellimus",
    "Url" : "URL",
    "Edit event" : "Muuda sündmust",
    "Delete Event" : "Kustuta sündmus",
    "Save Event" : "Salvesta sündmus",
    "Time" : "Aeg",
    "Type" : "Tüüp",
    "Relative" : "Suhteline",
    "Absolute" : "Absoluutne",
    "Repeat" : "Korda",
    "times every" : "korda iga",
    "Add" : "Lisa",
    "from" : "alates",
    "to" : "kuni",
    "Reset repeating rule" : "Nulli kordamise reegel",
    "Repeat every ..." : "Korda iga ...",
    "end repeat ..." : "lõpeta kordamine",
    "times" : "korda",
    "Import Calendars" : "Impordi kalendreid",
    "Import canceled" : "Importimine on tühistatud",
    "Analyzing calendar" : "Kalendri analüüsimine",
    "New calendar" : "Uus kalender",
    "Import scheduled" : "Importimine on ajastatud",
    "Settings" : "Seaded",
    "Import calendar" : "Impordi kalender",
    "No Calendars selected for import" : "Pole valitud kalendreid, mida importida",
    "Primary CalDAV address" : "Primaarne CalDAV aadress",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV aadress"
},
"nplurals=2; plural=(n != 1);");
